# Glossary

_Source: `glossary/glossary.yml` • v0.1.0 • Last reviewed 2025-08-09

Jump to: [A](#A) · [L](#L)

---

## A

### <a id="annual-average-daily-traffic"></a>Annual Average Daily Traffic

**Definition.** Total yearly traffic volume divided by 365.

**Aliases.** Average Annual Daily Traffic

**Category.** Traffic Volume

_term v0.1.0_

[Back to top](#glossary)

---

## L

### <a id="level-of-service"></a>Level of Service

**Definition.** Qualitative measure describing operational conditions.

**Category.** Performance Measures

_term v0.1.0_

[Back to top](#glossary)

---

